%-------------------------------------------------------------------------
% Post-traitement des résultats des solveurs de Navier-Stokes 
% NS_solveurDIR.m ou NS_solveurGUI.m (version GUI)
% Lecture de fichiers; affichage des solutions
%-------------------------------------------------------------------------
%
close all;
clear all;
fprintf('-------------------------------------------------------\n');
fprintf('                   Navier-Stokes 2D                    \n');
fprintf('   Lecture des fichiers de données / Post-traitement   \n');
fprintf('-------------------------------------------------------\n');

% Répertoire des fichiers à lire'
dir_name='Results_NS';
% Racine des fichiers
file_name='NS';
% Choix de l'affichage : 1-> vitesse; 2-> pression
type_affichage=1;

% Lecture des données de base (paramètres numériques, maillages,...)
nom_fich=strcat(dir_name,'/',file_name,'_numdata.dat');
S=load(nom_fich,'-ascii');
nbiter=S(1); pas_h=S(2); dt=S(3); T=S(4); nu=S(5);
nom_fich=strcat(dir_name,'/',file_name,'_v2.dat');
load(nom_fich,'v2','-mat');
nom_fich=strcat(dir_name,'/',file_name,'_t2.dat');
load(nom_fich,'t2','-mat');
nom_fich=strcat(dir_name,'/',file_name,'_v1.dat');
load(nom_fich,'v1','-mat');
nom_fich=strcat(dir_name,'/',file_name,'_t1.dat');
load(nom_fich,'t1','-mat');

nv1=size(v1,1); nv2=size(v2,1);
nt1=size(t1,1); nt2=size(t2,1); 

% Lecture des données
Ux=zeros(nv2,nbiter); Uy=Ux;
mod_U=zeros(nv2,nbiter);
maxmodU=0;
Pression=zeros(nv1,nbiter);
maxPr=-inf;
minPr=+inf;

fprintf('Lecture des fichiers (%d fichiers) : \n',nbiter);
fprintf('(1...20)=');
ntt=floor(nbiter/20)*20; j=1;

for it=1:nbiter
    
    if (mod(it*20,ntt)==0)
       fprintf(strcat(num2str(j),' '));
       j=j+1;
    end
    
    % Lecture de la vitesse
    nom_fich=sprintf('%s/%s_Ux_%.4d.dat',dir_name,file_name,it);
    load(nom_fich,'U2x','-mat');
    Ux(:,it)=U2x;
    nom_fich=sprintf('%s/%s_Uy_%.4d.dat',dir_name,file_name,it);
    load(nom_fich,'U2y','-mat');
    Uy(:,it)=U2y;
    mod_U(:,it)=sqrt(U2x.^2+U2y.^2);
    mmod=max(mod_U(:,it));
    if mmod> maxmodU, maxmodU=mmod; end;
       
    % Lecture de la pression
    nom_fich=sprintf('%s/%s_Pr_%.4d.dat',dir_name,file_name,it);
    load(nom_fich,'Pr','-mat')
    Pression(:,it)=Pr;
    minp=min(Pr); maxp=max(Pr);
    if maxp> maxPr, maxPr=maxp; end;
    if minp< minPr, minPr=minp; end;
end

fprintf('\nValeur max. du module de la vitesse = %f \n',maxmodU);

% Affichage
h1=figure('Position',[600 600 560 420]);
set(h1,'Color',[1 1 1]);  % Figure's background color = white
colormap('jet');

while 1
   
   fprintf('Affichage en cours...\n');
   
   for it=1:nbiter
      clf
      if type_affichage==1
         % Affichage du module de la vitesse
         patch('faces',t2(:,1:3),'vertices',v2(:,1:2),'FaceVertexCData',...
                mod_U(:,it),'facecolor','interp','edgecolor','none');
         %set(gca,'CLim',[0,maxmodU]);
         hold on
    
         % Affichage du champ de vitesse
         quiver(v1(:,1),v1(:,2),Ux(1:nv1,it),Uy(1:nv1,it));
         message=strcat('vitesse à t=',num2str(it*dt));
         hold off
      else
         % Affichage de la pression
         patch('faces',t1(:,1:3),'vertices',v1(:,1:2),'FaceVertexCData',...
               Pression(:,it),'facecolor','interp','edgecolor','black');
         %set(gca,'CLim',[minPr,maxPr]);
         message=strcat('pression à t=',num2str(it*dt));
      end
   
      axis image
      colorbar('northoutside');
      title(message)
      drawnow
   end
   
   reply = input('Encore une fois? O/N [N]: ', 's');
   if ((reply~='O' & reply~='o') | isempty(reply)), break; end;
   
end



