function [node,edge,pas_h,hdata,options]=geomDIR()
%--------------------------------------------------------------------------
% Définition de la géométrie et Maillage
%--------------------------------------------------------------------------
% node    : coordonnées [x;y] des noeuds du bord du domaine
% edge    : aretes du bord définies par les numeros des noeuds [n1, n2]
% hdata   : taille(s) du maillage
% options : options pour le maillage (dhmax,verbose...)
%
% Deux exemples sont proposés :
%
% Exemple 1: Domaine rectangle [0,L]x[0,H] (-> cavité entrainée)
%
% Exemple 2: Domaine non simplement connexe : rectangle [0,L]x[0,H] avec 
%            un obstacle (cercle/ellipse)  (-> Allée de Von Karman)
%--------------------------------------------------------------------------

global exemple

switch exemple
    
    case 1, 
        %------------------------------------------------------------------
        % Domaine rectangle [0,L]x[0,H]
        %------------------------------------------------------------------
        L=1; H=1;               
        
        node = [0 0; L 0; L H; 0 H];
        edge = [1 2; 2 3; 3 4; 4 1];

        % Taille du maillage
        pas_h=0.025;
        hdata = [];
        hdata.hmax  = pas_h;   

        options=[];
        %options.dhmax = 0.25;
        options.output=false;  % pas de sortie maillage
    
    case 2, 
        %------------------------------------------------------------------
        % Domaine rectangle [0,L]x[0,H] avec un obstacle (cercle/ellipse)
        %------------------------------------------------------------------
        L=2.2; H=0.41;
        
        node = [0 0; L 0; L H; 0 H];
        edge = [1 2; 2 3; 3 4; 4 1];

        % Taille du maillage
        pas_h=0.025;
        hdata = [];
        hdata.hmax  = pas_h;   

        options=[];
        %options.dhmax = 0.25;
        options.output=false;  % pas de sortie maillage
        
        
        % Construction de l'obstacle (ellipse)
                
        pxy=[0.2; 0.2];     % position (x,y) du centre de l'ellipse
        lgxy=[0.05; 0.05];  % longueurs des demi-axes et orientation
        angle=pi/4;         % orientation
        
        [node,edge] = obstacle(node,edge,pas_h,pxy,lgxy,angle);
        
end

end
