function [A,A1ibT,A2ibT,SS,icT]=matrixStokes(v1,t1,nv2,ibT,icT,nu,dt)
%--------------------------------------------------------------------------
% Construction des matrices de Stokes   
%--------------------------------------------------------------------------

nv1=size(v1,1); nt1=size(t1,1);

tstart=tic;
fprintf('-----------------------------------------------------------\n');
fprintf('Construction des matrices de Stokes                        \n');
fprintf('-----------------------------------------------------------\n');
fprintf('Construction des matrices P2 : ');

[DxDx,DyDy,DxDy,DxW,DyW,SS]=matrixP2vect(v1,t1);

fprintf('Construction des matrices P1 : ');

[DxDxP1,DyDyP1,WW]=matrixP1vect(v1,t1);

fprintf('Temps d''assemblage des matrices P1 et P2: %f s\n',toc(tstart));

% Matrices de Stokes : formulation D(u):D(v)

Minit=[(nu*2)*DxDx+nu*DyDy+SS/dt  nu*DxDy'             -DxW;
       nu*DxDy          nu*DxDx+(2*nu)*DyDy+SS/dt      -DyW;
       -DxW'                       -DyW'     sparse(nv1,nv1)];

M=[(nu*2)*DxDx+nu*DyDy+3*SS/(2*dt)  nu*DxDy'          -DxW;
    nu*DxDy          nu*DxDx+(2*nu)*DyDy+3*SS/(2*dt)  -DyW;
    -DxW'                       -DyW'     sparse(nv1,nv1)];

% Calcul de la moyenne de la pression (multiplicateur de Lagrange)

un=ones(nv1,1);
w=zeros(nv1,1);
for k=1:nt1
    pt=t1(k,1:3);
    aire=t1(k,5);
    w(pt)=w(pt)+aire/3;
end
C=[sparse(2*nv2,1);w/(w'*un)];

icT = [icT; 2*nv2+nv1+1]; %ajout du multiplicatuer comme inconnue

% Matrice de Stokes utilisée pour le schéma d'ordre 1 à la premiere 
% iteration it=1.
Ainit=[Minit C;
       C'    0];
   
% Matrice de Stokes utilisée à partir de l'itération it>1, pour
% le schéma de convection d'ordre 2 en temps
A=[M  C;
   C' 0];

% Gestion des conditions limites

A1ibT=Ainit(:,ibT); % pour l'iteration it=1 (convection ordre 1)
A2ibT=A(:,ibT);     % pour l'iteration it>1 (convection ordre 2)

% Dans la matrice A de Stokes, on ne retient que les noeuds interieurs 
% (i.e. les noeuds qui ne sont pas sur le bord).
% Remarque : L'instruction A=A(icT,:); A=A(:,icT) est beaucoup plus 
%            rapide que l'instruction A(ibT,:)=[];A(:,ibT)=[]; qui 
%            consiste à supprimer les noeuds du bord.
A=A(icT,:); A=A(:,icT);

end

